%undefine __cmake_in_source_build
%global plugins_version 4.0

Summary:	Network traffic analyzer
Name:		wireshark
Version:	4.0.10
Release:	4%{?dist}
License:	GPL+
Url:		http://www.wireshark.org/

Source0:	https://wireshark.org/download/src/%{name}-%{version}.tar.xz
Source1:	90-wireshark-usbmon.rules
Source2:	wireshark.sysusers

Patch0001:	CVE-2023-6174.patch
Patch0002:	CVE-2023-6175.patch
Patch0003:	CVE-2024-0208.patch
Patch0004:	CVE-2024-0209.patch
Patch3000:	wireshark-0002-Customize-permission-denied-error.patch
Patch3001:	wireshark-0003-fix-string-overrun-in-plugins-profinet.patch
Patch3002:	wireshark-0004-Restore-Fedora-specific-groups.patch
Patch3003:	wireshark-0005-Fix-paths-in-a-wireshark.desktop-file.patch
Patch3004:	wireshark-0006-Move-tmp-to-var-tmp.patch
Patch3005:	wireshark-0007-cmakelists.patch

BuildRequires: qt5-qtbase-devel qt5-qtmultimedia-devel qt5-qtsvg-devel
BuildRequires: systemd-devel libnghttp2-devel systemd-rpm-macros qt5-qttools-devel qt5-linguist
BuildRequires: zlib-devel asciidoctor libmaxminddb-devel
BuildRequires: perl(open) pcre2-devel xdg-utils bison
BuildRequires: flex perl(Pod::Html) perl(Pod::Man)
BuildRequires: libsmi-devel openssl-devel desktop-file-utils
BuildRequires: libcap-devel libgcrypt-devel libpcap-devel >= 0.9 libnl3-devel
BuildRequires: gnutls-devel krb5-devel libselinux-devel
BuildRequires: elfutils-devel gcc-c++ glib2-devel
BuildRequires: bzip2-devel c-ares-devel

Requires:      %{name}-cli = %{version}-%{release}
Requires:      xdg-utils
Requires:      hicolor-icon-theme
Requires:      libmaxminddb

%description
Wireshark allows you to examine protocol data stored in files or as it is
captured from wired or wireless (WiFi or Bluetooth) networks, USB devices,
and many other sources.  It supports dozens of protocol capture file formats
and understands more than a thousand protocols.

It has many powerful features including a rich display filter language
and the ability to reassemble multiple protocol packets in order to, for
example, view a complete TCP stream, save the contents of a file which was
transferred over HTTP or CIFS, or play back an RTP audio stream.

%package	cli
Summary:	Network traffic analyzer
Requires(pre):	shadow-utils
Requires(post): systemd-udev

%description cli
This package contains command-line utilities, plugins, and documentation for
Wireshark.

%package devel
Summary:	Development headers and libraries for wireshark
Requires:	%{name} = %{version}-%{release} glibc-devel glib2-devel

%description devel
The wireshark-devel package contains the header files, developer
documentation, and libraries required for development of wireshark scripts
and plugins.


%prep
%autosetup -p1

%build
%cmake -G "Unix Makefiles" \
  -DDISABLE_WERROR=ON \
  -DBUILD_wireshark=ON \
  -DENABLE_LUA=ON \
  -DBUILD_mmdbresolve=ON \
  -DBUILD_randpktdump=OFF \
  -DBUILD_androiddump=ON \
  -DENABLE_SMI=ON \
  -DUSE_qt6=OFF \
  -DENABLE_PLUGINS=ON \
  -DENABLE_NETLINK=ON \
  -DBUILD_dcerpcidl2wrs=OFF \
  -DBUILD_sdjournal=ON

%cmake_build

%install
%cmake_install

desktop-file-validate %{buildroot}%{_datadir}/applications/org.wireshark.Wireshark.desktop

install -dm0755  %{buildroot}%{_includedir}/wireshark
IDIR="%{buildroot}%{_includedir}/wireshark"
mkdir -p "${IDIR}/epan"
mkdir -p "${IDIR}/epan/crypt"
mkdir -p "${IDIR}/epan/ftypes"
mkdir -p "${IDIR}/epan/dfilter"
mkdir -p "${IDIR}/epan/dissectors"
mkdir -p "${IDIR}/epan/wmem"
mkdir -p "${IDIR}/wiretap"
mkdir -p "${IDIR}/wsutil"
mkdir -p %{buildroot}%{_udevrulesdir}
install -m 644 %{_vpath_builddir}/config.h epan/register.h	"${IDIR}/"
install -m 644 cfile.h file.h		"${IDIR}/"
install -m 644 epan/*.h			"${IDIR}/epan/"
install -m 644 epan/crypt/*.h		"${IDIR}/epan/crypt"
install -m 644 epan/ftypes/*.h		"${IDIR}/epan/ftypes"
install -m 644 epan/dfilter/*.h		"${IDIR}/epan/dfilter"
install -m 644 epan/dissectors/*.h	"${IDIR}/epan/dissectors"
install -m 644 wiretap/*.h		"${IDIR}/wiretap"
install -m 644 wsutil/*.h		"${IDIR}/wsutil"
install -m 644 include/ws_symbol_export.h    "${IDIR}/"
install -m 644 include/ws_diag_control.h    "${IDIR}/"
install -m 644 %{SOURCE1}		%{buildroot}%{_udevrulesdir}
install -Dpm 644 %{SOURCE2}		%{buildroot}%{_sysusersdir}/%{name}.conf

touch %{buildroot}%{_bindir}/%{name}

find %{buildroot} -type f -name "*.la" -delete

%pre cli
%sysusers_create_compat %{SOURCE3}

%post cli
if [ -S /run/udev/control ]; then
    /usr/bin/udevadm trigger --subsystem-match=usbmon
fi


%files
%{_bindir}/wireshark
%{_datadir}/applications/org.wireshark.Wireshark.desktop
%{_datadir}/metainfo/*.xml
%{_datadir}/mime/packages/*.xml
%{_datadir}/icons/hicolor/*/apps/*
%{_datadir}/icons/hicolor/*/mimetypes/*
%{_sysusersdir}/%{name}.conf
%{_mandir}/man1/wireshark.*

%files cli
%license COPYING
%doc AUTHORS INSTALL NEWS README*
%{_bindir}/capinfos
%{_bindir}/captype
%{_bindir}/editcap
%{_bindir}/mergecap
%{_bindir}/randpkt
%{_bindir}/reordercap
%{_bindir}/sharkd
%{_bindir}/text2pcap
%{_bindir}/tshark
%{_bindir}/mmdbresolve
%{_bindir}/rawshark
%attr(0750, root, wireshark) %caps(cap_net_raw,cap_net_admin=ep) %{_bindir}/dumpcap
%{_udevrulesdir}/90-wireshark-usbmon.rules
%{_libdir}/lib*.so.*
%dir %{_libdir}/wireshark
%dir %{_libdir}/wireshark/extcap
%dir %{_libdir}/wireshark/plugins
%{_libdir}/wireshark/extcap/udpdump
%{_libdir}/wireshark/extcap/sdjournal
%{_libdir}/wireshark/extcap/dpauxmon
%{_libdir}/wireshark/extcap/androiddump
%dir %{_libdir}/wireshark/cmake
%{_libdir}/wireshark/cmake/*.cmake
%dir %{_libdir}/wireshark/plugins/%{plugins_version}
%dir %{_libdir}/wireshark/plugins/%{plugins_version}/epan
%dir %{_libdir}/wireshark/plugins/%{plugins_version}/wiretap
%dir %{_libdir}/wireshark/plugins/%{plugins_version}/codecs
%{_libdir}/wireshark/plugins/%{plugins_version}/epan/*.so
%{_libdir}/wireshark/plugins/%{plugins_version}/wiretap/*.so
%{_libdir}/wireshark/plugins/%{plugins_version}/codecs/*.so
%dir %{_datadir}/wireshark
%{_datadir}/wireshark/*
%{_mandir}/man1/editcap.*
%{_mandir}/man1/tshark.*
%{_mandir}/man1/mergecap.*
%{_mandir}/man1/text2pcap.*
%{_mandir}/man1/capinfos.*
%{_mandir}/man1/dumpcap.*
%{_mandir}/man4/wireshark-filter.*
%{_mandir}/man1/rawshark.*
%{_mandir}/man1/dftest.*
%{_mandir}/man1/randpkt.*
%{_mandir}/man1/reordercap.*
%{_mandir}/man1/sshdump.*
%{_mandir}/man1/udpdump.*
%{_mandir}/man1/wifidump.*
%{_mandir}/man1/androiddump.*
%{_mandir}/man1/captype.*
%{_mandir}/man1/ciscodump.*
%{_mandir}/man1/randpktdump.*
%{_mandir}/man1/dpauxmon.*
%{_mandir}/man1/sdjournal.*
%{_mandir}/man1/etwdump.1.gz
%{_mandir}/man4/extcap.*
%{_mandir}/man1/mmdbresolve.*

%files devel
%doc doc/README.* ChangeLog
%{_includedir}/wireshark
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Tue Jan 30 2024 Miaojun Dong <zoedong@tencent.com> - 4.0.10-4
- Fix CVE-2024-0208
- Fix CVE-2024-0209

* Wed Jan 17 2024 Rebuild Robot <rebot@opencloudos.org> - 4.0.10-3
- Rebuilt for elfutils

* Mon Dec 11 2023 Miaojun Dong <zoedong@tencent.com> - 4.0.10-2
- Fix CVE-2023-6174
- Fix CVE-2023-6175

* Thu Nov 09 2023 Miaojun Dong <zoedong@tencent.com> - 4.0.10-1
- Upgrade version to 4.0.10

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.0.1-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.0.1-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.0.1-2
- Rebuilt for OpenCloudOS Stream 23

* Thu Mar 16 2023 cunshunxia <cunshunxia@tencent.com> - 4.0.1-1
- initial build
